@@ -209,11 +209,9 @@ describe 'horizon' do
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           "OVERVIEW_DAYS_RANGE = 1",
-          'DISALLOW_IFRAME_EMBED = True',
         ])
       end
 
-      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with_ensure('directory') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
 
@@ -574,16 +572,16 @@ describe 'horizon' do
       end
     end
 
-    context 'with disallow iframe embed disabled' do
+    context 'with disallow iframe embed enabled' do
       before do
         params.merge!({
-                        :disallow_iframe_embed => false
+                        :disallow_iframe_embed => true
                       })
       end
 
       it 'disallow_iframe_embed is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'DISALLOW_IFRAME_EMBED = False',
+                                          'HORIZON_CONFIG["disallow_iframe_embed"] = True',
                                         ])
       end
     end
@@ -591,32 +589,51 @@ describe 'horizon' do
     context 'with websso enabled' do
       before do
         params.merge!({
-                        :websso_enabled => 'True',
-                        :websso_initial_choice => 'acme',
-                        :websso_choices => [
-                          ['oidc', 'OpenID Connect'],
-                          ['saml2', 'Security Assertion Markup Language'],
-                        ],
-                        :websso_idp_mapping => {
-                          'acme_oidc'  => ['acme', 'oidc'],
-                          'acme_saml2' => ['acme', 'saml2'],
-                        }
-                      })
+            :websso_enabled => 'True',
+            :websso_initial_choice => 'acme',
+            :websso_choices => [
+              ['oidc', 'OpenID Connect'],
+              ['saml2', 'Security Assertion Markup Language'],
+            ],
+            :websso_idp_mapping => {
+              'acme_oidc'  => ['acme', 'oidc'],
+              'acme_saml2' => ['acme', 'saml2'],
+            }
+          })
       end
       it 'configures websso options' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'WEBSSO_ENABLED = True',
-                                          'WEBSSO_INITIAL_CHOICE = "acme"',
-                                          'WEBSSO_CHOICES = (',
-                                          '    ("credentials", _("Keystone Credentials")),',
-                                          '    ("oidc", _("OpenID Connect")),',
-                                          '    ("saml2", _("Security Assertion Markup Language")),',
-                                          ')',
-                                          'WEBSSO_IDP_MAPPING = {',
-                                          '    "acme_oidc": ("acme", "oidc"),',
-                                          '    "acme_saml2": ("acme", "saml2"),',
-                                          '}',
-                                        ])
+          'WEBSSO_ENABLED = True',
+          'WEBSSO_INITIAL_CHOICE = "acme"',
+          'WEBSSO_CHOICES = (',
+          '    ("credentials", _("Keystone Credentials")),',
+          '    ("oidc", _("OpenID Connect")),',
+          '    ("saml2", _("Security Assertion Markup Language")),',
+          ')',
+          'WEBSSO_IDP_MAPPING = {',
+          '    "acme_oidc": ("acme", "oidc"),',
+          '    "acme_saml2": ("acme", "saml2"),',
+          '}',
+          ])
+      end
+    end
+
+    context 'with websso redirect enabled' do
+      before do
+        params.merge!({
+          :websso_default_redirect          => true,
+          :websso_default_redirect_protocol => 'oidc',
+          :websso_default_redirect_region   => 'http://127.0.0.1:5000',
+          :websso_default_redirect_logout   => 'http://idptest/logout'
+        })
+      end
+      it 'configures websso redirect options' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'WEBSSO_DEFAULT_REDIRECT = True',
+          'WEBSSO_DEFAULT_REDIRECT_PROTOCOL = "oidc"',
+          'WEBSSO_DEFAULT_REDIRECT_REGION = "http://127.0.0.1:5000"',
+          'WEBSSO_DEFAULT_REDIRECT_LOGOUT = "http://idptest/logout"'
+          ])
       end
     end
 
@@ -750,7 +767,6 @@ describe 'horizon' do
         when 'Debian'
           if facts[:os_package_type] == 'debian'
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard-apache',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -758,7 +774,6 @@ describe 'horizon' do
             }
           else
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -766,33 +781,12 @@ describe 'horizon' do
             }
           end
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :config_file      => '/etc/openstack-dashboard/local_settings',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
-              :package_name     => 'openstack-dashboard',
-              :root_url         => '/dashboard',
-              :root_path        => '/usr/share/openstack-dashboard',
-              :memcache_package => 'python3-memcached',
-            }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :config_file      => '/etc/openstack-dashboard/local_settings',
-                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
-                :package_name     => 'openstack-dashboard',
-                :root_url         => '/dashboard',
-                :root_path        => '/usr/share/openstack-dashboard',
-                :memcache_package => 'python3-memcached',
-              }
-            else
-              { :config_file      => '/etc/openstack-dashboard/local_settings',
-                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
-                :package_name     => 'openstack-dashboard',
-                :root_url         => '/dashboard',
-                :root_path        => '/usr/share/openstack-dashboard',
-                :memcache_package => 'python-memcached',
-              }
-            end
-          end
+          { :config_file      => '/etc/openstack-dashboard/local_settings',
+            :package_name     => 'openstack-dashboard',
+            :root_url         => '/dashboard',
+            :root_path        => '/usr/share/openstack-dashboard',
+            :memcache_package => 'python3-memcached',
+          }
         end
       end
 
